# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/MonsterUI',
                'doc_host': 'https://monsterui.answer.ai',
                'git_url': 'https://github.com/AnswerDotAI/MonsterUI',
                'lib_path': 'monsterui'},
  'syms': { 'monsterui.all': {},
            'monsterui.core': { 'monsterui.core.FastHTML': ('core.html#fasthtml', 'monsterui/core.py'),
                                'monsterui.core.Theme': ('core.html#theme', 'monsterui/core.py'),
                                'monsterui.core.Theme._create_headers': ('core.html#theme._create_headers', 'monsterui/core.py'),
                                'monsterui.core.Theme._generate_next_value_': ( 'core.html#theme._generate_next_value_',
                                                                                'monsterui/core.py'),
                                'monsterui.core.Theme.headers': ('core.html#theme.headers', 'monsterui/core.py'),
                                'monsterui.core.Theme.local_headers': ('core.html#theme.local_headers', 'monsterui/core.py'),
                                'monsterui.core.ThemeFont': ('core.html#themefont', 'monsterui/core.py'),
                                'monsterui.core.ThemeRadii': ('core.html#themeradii', 'monsterui/core.py'),
                                'monsterui.core.ThemeShadows': ('core.html#themeshadows', 'monsterui/core.py'),
                                'monsterui.core._download_resource': ('core.html#_download_resource', 'monsterui/core.py'),
                                'monsterui.core._headers_theme': ('core.html#_headers_theme', 'monsterui/core.py'),
                                'monsterui.core.fast_app': ('core.html#fast_app', 'monsterui/core.py')},
            'monsterui.daisy': { 'monsterui.daisy.Alert': ('daisy.html#alert', 'monsterui/daisy.py'),
                                 'monsterui.daisy.AlertT': ('daisy.html#alertt', 'monsterui/daisy.py'),
                                 'monsterui.daisy.AlertT._generate_next_value_': ( 'daisy.html#alertt._generate_next_value_',
                                                                                   'monsterui/daisy.py'),
                                 'monsterui.daisy.LiStep': ('daisy.html#listep', 'monsterui/daisy.py'),
                                 'monsterui.daisy.Loading': ('daisy.html#loading', 'monsterui/daisy.py'),
                                 'monsterui.daisy.LoadingT': ('daisy.html#loadingt', 'monsterui/daisy.py'),
                                 'monsterui.daisy.LoadingT._generate_next_value_': ( 'daisy.html#loadingt._generate_next_value_',
                                                                                     'monsterui/daisy.py'),
                                 'monsterui.daisy.StepT': ('daisy.html#stept', 'monsterui/daisy.py'),
                                 'monsterui.daisy.StepT._generate_next_value_': ( 'daisy.html#stept._generate_next_value_',
                                                                                  'monsterui/daisy.py'),
                                 'monsterui.daisy.Steps': ('daisy.html#steps', 'monsterui/daisy.py'),
                                 'monsterui.daisy.StepsT': ('daisy.html#stepst', 'monsterui/daisy.py'),
                                 'monsterui.daisy.StepsT._generate_next_value_': ( 'daisy.html#stepst._generate_next_value_',
                                                                                   'monsterui/daisy.py'),
                                 'monsterui.daisy.Toast': ('daisy.html#toast', 'monsterui/daisy.py'),
                                 'monsterui.daisy.ToastHT': ('daisy.html#toastht', 'monsterui/daisy.py'),
                                 'monsterui.daisy.ToastHT._generate_next_value_': ( 'daisy.html#toastht._generate_next_value_',
                                                                                    'monsterui/daisy.py'),
                                 'monsterui.daisy.ToastVT': ('daisy.html#toastvt', 'monsterui/daisy.py'),
                                 'monsterui.daisy.ToastVT._generate_next_value_': ( 'daisy.html#toastvt._generate_next_value_',
                                                                                    'monsterui/daisy.py')},
            'monsterui.foundations': { 'monsterui.foundations.VEnum': ('foundation.html#venum', 'monsterui/foundations.py'),
                                       'monsterui.foundations.VEnum.__add__': ('foundation.html#venum.__add__', 'monsterui/foundations.py'),
                                       'monsterui.foundations.VEnum.__radd__': ( 'foundation.html#venum.__radd__',
                                                                                 'monsterui/foundations.py'),
                                       'monsterui.foundations.VEnum.__str__': ('foundation.html#venum.__str__', 'monsterui/foundations.py'),
                                       'monsterui.foundations.str2ukcls': ('foundation.html#str2ukcls', 'monsterui/foundations.py'),
                                       'monsterui.foundations.stringify': ('foundation.html#stringify', 'monsterui/foundations.py')},
            'monsterui.franken': { 'monsterui.franken.AT': ('franken.html#at', 'monsterui/franken.py'),
                                   'monsterui.franken.AT._generate_next_value_': ( 'franken.html#at._generate_next_value_',
                                                                                   'monsterui/franken.py'),
                                   'monsterui.franken.Abbr': ('franken.html#abbr', 'monsterui/franken.py'),
                                   'monsterui.franken.Address': ('franken.html#address', 'monsterui/franken.py'),
                                   'monsterui.franken.Article': ('franken.html#article', 'monsterui/franken.py'),
                                   'monsterui.franken.ArticleMeta': ('franken.html#articlemeta', 'monsterui/franken.py'),
                                   'monsterui.franken.ArticleTitle': ('franken.html#articletitle', 'monsterui/franken.py'),
                                   'monsterui.franken.BackgroundT': ('franken.html#backgroundt', 'monsterui/franken.py'),
                                   'monsterui.franken.BackgroundT._generate_next_value_': ( 'franken.html#backgroundt._generate_next_value_',
                                                                                            'monsterui/franken.py'),
                                   'monsterui.franken.Blockquote': ('franken.html#blockquote', 'monsterui/franken.py'),
                                   'monsterui.franken.Button': ('franken.html#button', 'monsterui/franken.py'),
                                   'monsterui.franken.ButtonT': ('franken.html#buttont', 'monsterui/franken.py'),
                                   'monsterui.franken.ButtonT._generate_next_value_': ( 'franken.html#buttont._generate_next_value_',
                                                                                        'monsterui/franken.py'),
                                   'monsterui.franken.Caption': ('franken.html#caption', 'monsterui/franken.py'),
                                   'monsterui.franken.Card': ('franken.html#card', 'monsterui/franken.py'),
                                   'monsterui.franken.CardBody': ('franken.html#cardbody', 'monsterui/franken.py'),
                                   'monsterui.franken.CardContainer': ('franken.html#cardcontainer', 'monsterui/franken.py'),
                                   'monsterui.franken.CardFooter': ('franken.html#cardfooter', 'monsterui/franken.py'),
                                   'monsterui.franken.CardHeader': ('franken.html#cardheader', 'monsterui/franken.py'),
                                   'monsterui.franken.CardT': ('franken.html#cardt', 'monsterui/franken.py'),
                                   'monsterui.franken.CardT._generate_next_value_': ( 'franken.html#cardt._generate_next_value_',
                                                                                      'monsterui/franken.py'),
                                   'monsterui.franken.CardTitle': ('franken.html#cardtitle', 'monsterui/franken.py'),
                                   'monsterui.franken.Center': ('franken.html#center', 'monsterui/franken.py'),
                                   'monsterui.franken.CheckboxX': ('franken.html#checkboxx', 'monsterui/franken.py'),
                                   'monsterui.franken.Cite': ('franken.html#cite', 'monsterui/franken.py'),
                                   'monsterui.franken.CodeBlock': ('franken.html#codeblock', 'monsterui/franken.py'),
                                   'monsterui.franken.CodeSpan': ('franken.html#codespan', 'monsterui/franken.py'),
                                   'monsterui.franken.Container': ('franken.html#container', 'monsterui/franken.py'),
                                   'monsterui.franken.ContainerT': ('franken.html#containert', 'monsterui/franken.py'),
                                   'monsterui.franken.ContainerT._generate_next_value_': ( 'franken.html#containert._generate_next_value_',
                                                                                           'monsterui/franken.py'),
                                   'monsterui.franken.Data': ('franken.html#data', 'monsterui/franken.py'),
                                   'monsterui.franken.Del': ('franken.html#del', 'monsterui/franken.py'),
                                   'monsterui.franken.Details': ('franken.html#details', 'monsterui/franken.py'),
                                   'monsterui.franken.Dfn': ('franken.html#dfn', 'monsterui/franken.py'),
                                   'monsterui.franken.DiceBearAvatar': ('franken.html#dicebearavatar', 'monsterui/franken.py'),
                                   'monsterui.franken.DivCentered': ('franken.html#divcentered', 'monsterui/franken.py'),
                                   'monsterui.franken.DivFullySpaced': ('franken.html#divfullyspaced', 'monsterui/franken.py'),
                                   'monsterui.franken.DivHStacked': ('franken.html#divhstacked', 'monsterui/franken.py'),
                                   'monsterui.franken.DivLAligned': ('franken.html#divlaligned', 'monsterui/franken.py'),
                                   'monsterui.franken.DivRAligned': ('franken.html#divraligned', 'monsterui/franken.py'),
                                   'monsterui.franken.DivVStacked': ('franken.html#divvstacked', 'monsterui/franken.py'),
                                   'monsterui.franken.Divider': ('franken.html#divider', 'monsterui/franken.py'),
                                   'monsterui.franken.DividerLine': ('franken.html#dividerline', 'monsterui/franken.py'),
                                   'monsterui.franken.DividerSplit': ('franken.html#dividersplit', 'monsterui/franken.py'),
                                   'monsterui.franken.DividerT': ('franken.html#dividert', 'monsterui/franken.py'),
                                   'monsterui.franken.DividerT._generate_next_value_': ( 'franken.html#dividert._generate_next_value_',
                                                                                         'monsterui/franken.py'),
                                   'monsterui.franken.DropDownNavContainer': ('franken.html#dropdownnavcontainer', 'monsterui/franken.py'),
                                   'monsterui.franken.Em': ('franken.html#em', 'monsterui/franken.py'),
                                   'monsterui.franken.Fieldset': ('franken.html#fieldset', 'monsterui/franken.py'),
                                   'monsterui.franken.Figure': ('franken.html#figure', 'monsterui/franken.py'),
                                   'monsterui.franken.FlexT': ('franken.html#flext', 'monsterui/franken.py'),
                                   'monsterui.franken.FlexT._generate_next_value_': ( 'franken.html#flext._generate_next_value_',
                                                                                      'monsterui/franken.py'),
                                   'monsterui.franken.Form': ('franken.html#form', 'monsterui/franken.py'),
                                   'monsterui.franken.FormLabel': ('franken.html#formlabel', 'monsterui/franken.py'),
                                   'monsterui.franken.GenericLabelInput': ('franken.html#genericlabelinput', 'monsterui/franken.py'),
                                   'monsterui.franken.Grid': ('franken.html#grid', 'monsterui/franken.py'),
                                   'monsterui.franken.H1': ('franken.html#h1', 'monsterui/franken.py'),
                                   'monsterui.franken.H2': ('franken.html#h2', 'monsterui/franken.py'),
                                   'monsterui.franken.H3': ('franken.html#h3', 'monsterui/franken.py'),
                                   'monsterui.franken.H4': ('franken.html#h4', 'monsterui/franken.py'),
                                   'monsterui.franken.H5': ('franken.html#h5', 'monsterui/franken.py'),
                                   'monsterui.franken.H6': ('franken.html#h6', 'monsterui/franken.py'),
                                   'monsterui.franken.I': ('franken.html#i', 'monsterui/franken.py'),
                                   'monsterui.franken.Input': ('franken.html#input', 'monsterui/franken.py'),
                                   'monsterui.franken.Ins': ('franken.html#ins', 'monsterui/franken.py'),
                                   'monsterui.franken.Kbd': ('franken.html#kbd', 'monsterui/franken.py'),
                                   'monsterui.franken.Label': ('franken.html#label', 'monsterui/franken.py'),
                                   'monsterui.franken.LabelCheckboxX': ('franken.html#labelcheckboxx', 'monsterui/franken.py'),
                                   'monsterui.franken.LabelInput': ('franken.html#labelinput', 'monsterui/franken.py'),
                                   'monsterui.franken.LabelRadio': ('franken.html#labelradio', 'monsterui/franken.py'),
                                   'monsterui.franken.LabelRange': ('franken.html#labelrange', 'monsterui/franken.py'),
                                   'monsterui.franken.LabelSelect': ('franken.html#labelselect', 'monsterui/franken.py'),
                                   'monsterui.franken.LabelSwitch': ('franken.html#labelswitch', 'monsterui/franken.py'),
                                   'monsterui.franken.LabelT': ('franken.html#labelt', 'monsterui/franken.py'),
                                   'monsterui.franken.LabelT._generate_next_value_': ( 'franken.html#labelt._generate_next_value_',
                                                                                       'monsterui/franken.py'),
                                   'monsterui.franken.LabelTextArea': ('franken.html#labeltextarea', 'monsterui/franken.py'),
                                   'monsterui.franken.Legend': ('franken.html#legend', 'monsterui/franken.py'),
                                   'monsterui.franken.LightboxContainer': ('franken.html#lightboxcontainer', 'monsterui/franken.py'),
                                   'monsterui.franken.LightboxItem': ('franken.html#lightboxitem', 'monsterui/franken.py'),
                                   'monsterui.franken.ListT': ('franken.html#listt', 'monsterui/franken.py'),
                                   'monsterui.franken.Mark': ('franken.html#mark', 'monsterui/franken.py'),
                                   'monsterui.franken.Meter': ('franken.html#meter', 'monsterui/franken.py'),
                                   'monsterui.franken.Modal': ('franken.html#modal', 'monsterui/franken.py'),
                                   'monsterui.franken.ModalBody': ('franken.html#modalbody', 'monsterui/franken.py'),
                                   'monsterui.franken.ModalCloseButton': ('franken.html#modalclosebutton', 'monsterui/franken.py'),
                                   'monsterui.franken.ModalContainer': ('franken.html#modalcontainer', 'monsterui/franken.py'),
                                   'monsterui.franken.ModalDialog': ('franken.html#modaldialog', 'monsterui/franken.py'),
                                   'monsterui.franken.ModalFooter': ('franken.html#modalfooter', 'monsterui/franken.py'),
                                   'monsterui.franken.ModalHeader': ('franken.html#modalheader', 'monsterui/franken.py'),
                                   'monsterui.franken.ModalTitle': ('franken.html#modaltitle', 'monsterui/franken.py'),
                                   'monsterui.franken.NavBar': ('franken.html#navbar', 'monsterui/franken.py'),
                                   'monsterui.franken.NavCloseLi': ('franken.html#navcloseli', 'monsterui/franken.py'),
                                   'monsterui.franken.NavContainer': ('franken.html#navcontainer', 'monsterui/franken.py'),
                                   'monsterui.franken.NavDividerLi': ('franken.html#navdividerli', 'monsterui/franken.py'),
                                   'monsterui.franken.NavHeaderLi': ('franken.html#navheaderli', 'monsterui/franken.py'),
                                   'monsterui.franken.NavParentLi': ('franken.html#navparentli', 'monsterui/franken.py'),
                                   'monsterui.franken.NavSubtitle': ('franken.html#navsubtitle', 'monsterui/franken.py'),
                                   'monsterui.franken.NavT': ('franken.html#navt', 'monsterui/franken.py'),
                                   'monsterui.franken.NavT._generate_next_value_': ( 'franken.html#navt._generate_next_value_',
                                                                                     'monsterui/franken.py'),
                                   'monsterui.franken.Options': ('franken.html#options', 'monsterui/franken.py'),
                                   'monsterui.franken.Output': ('franken.html#output', 'monsterui/franken.py'),
                                   'monsterui.franken.PicSumImg': ('franken.html#picsumimg', 'monsterui/franken.py'),
                                   'monsterui.franken.Placeholder': ('franken.html#placeholder', 'monsterui/franken.py'),
                                   'monsterui.franken.Progress': ('franken.html#progress', 'monsterui/franken.py'),
                                   'monsterui.franken.Q': ('franken.html#q', 'monsterui/franken.py'),
                                   'monsterui.franken.Radio': ('franken.html#radio', 'monsterui/franken.py'),
                                   'monsterui.franken.Range': ('franken.html#range', 'monsterui/franken.py'),
                                   'monsterui.franken.S': ('franken.html#s', 'monsterui/franken.py'),
                                   'monsterui.franken.Samp': ('franken.html#samp', 'monsterui/franken.py'),
                                   'monsterui.franken.ScrollspyT': ('franken.html#scrollspyt', 'monsterui/franken.py'),
                                   'monsterui.franken.Section': ('franken.html#section', 'monsterui/franken.py'),
                                   'monsterui.franken.SectionT': ('franken.html#sectiont', 'monsterui/franken.py'),
                                   'monsterui.franken.SectionT._generate_next_value_': ( 'franken.html#sectiont._generate_next_value_',
                                                                                         'monsterui/franken.py'),
                                   'monsterui.franken.Select': ('franken.html#select', 'monsterui/franken.py'),
                                   'monsterui.franken.Slider': ('franken.html#slider', 'monsterui/franken.py'),
                                   'monsterui.franken.SliderContainer': ('franken.html#slidercontainer', 'monsterui/franken.py'),
                                   'monsterui.franken.SliderItems': ('franken.html#slideritems', 'monsterui/franken.py'),
                                   'monsterui.franken.SliderNav': ('franken.html#slidernav', 'monsterui/franken.py'),
                                   'monsterui.franken.Small': ('franken.html#small', 'monsterui/franken.py'),
                                   'monsterui.franken.Strong': ('franken.html#strong', 'monsterui/franken.py'),
                                   'monsterui.franken.Sub': ('franken.html#sub', 'monsterui/franken.py'),
                                   'monsterui.franken.Subtitle': ('franken.html#subtitle', 'monsterui/franken.py'),
                                   'monsterui.franken.Summary': ('franken.html#summary', 'monsterui/franken.py'),
                                   'monsterui.franken.Sup': ('franken.html#sup', 'monsterui/franken.py'),
                                   'monsterui.franken.Switch': ('franken.html#switch', 'monsterui/franken.py'),
                                   'monsterui.franken.TabContainer': ('franken.html#tabcontainer', 'monsterui/franken.py'),
                                   'monsterui.franken.Table': ('franken.html#table', 'monsterui/franken.py'),
                                   'monsterui.franken.TableFromDicts': ('franken.html#tablefromdicts', 'monsterui/franken.py'),
                                   'monsterui.franken.TableFromLists': ('franken.html#tablefromlists', 'monsterui/franken.py'),
                                   'monsterui.franken.TableT': ('franken.html#tablet', 'monsterui/franken.py'),
                                   'monsterui.franken.TableT._generate_next_value_': ( 'franken.html#tablet._generate_next_value_',
                                                                                       'monsterui/franken.py'),
                                   'monsterui.franken.Tbody': ('franken.html#tbody', 'monsterui/franken.py'),
                                   'monsterui.franken.Td': ('franken.html#td', 'monsterui/franken.py'),
                                   'monsterui.franken.TextArea': ('franken.html#textarea', 'monsterui/franken.py'),
                                   'monsterui.franken.TextPresets': ('franken.html#textpresets', 'monsterui/franken.py'),
                                   'monsterui.franken.TextT': ('franken.html#textt', 'monsterui/franken.py'),
                                   'monsterui.franken.TextT._generate_next_value_': ( 'franken.html#textt._generate_next_value_',
                                                                                      'monsterui/franken.py'),
                                   'monsterui.franken.Th': ('franken.html#th', 'monsterui/franken.py'),
                                   'monsterui.franken.ThemePicker': ('franken.html#themepicker', 'monsterui/franken.py'),
                                   'monsterui.franken.Time': ('franken.html#time', 'monsterui/franken.py'),
                                   'monsterui.franken.Titled': ('franken.html#titled', 'monsterui/franken.py'),
                                   'monsterui.franken.U': ('franken.html#u', 'monsterui/franken.py'),
                                   'monsterui.franken.UkFormSection': ('franken.html#ukformsection', 'monsterui/franken.py'),
                                   'monsterui.franken.UkIcon': ('franken.html#ukicon', 'monsterui/franken.py'),
                                   'monsterui.franken.UkIconLink': ('franken.html#ukiconlink', 'monsterui/franken.py'),
                                   'monsterui.franken.Upload': ('franken.html#upload', 'monsterui/franken.py'),
                                   'monsterui.franken.UploadZone': ('franken.html#uploadzone', 'monsterui/franken.py'),
                                   'monsterui.franken.Var': ('franken.html#var', 'monsterui/franken.py'),
                                   'monsterui.franken._TableCell': ('franken.html#_tablecell', 'monsterui/franken.py'),
                                   'monsterui.franken.apply_classes': ('franken.html#apply_classes', 'monsterui/franken.py'),
                                   'monsterui.franken.get_franken_renderer': ('franken.html#get_franken_renderer', 'monsterui/franken.py'),
                                   'monsterui.franken.render_md': ('franken.html#render_md', 'monsterui/franken.py')}}}
